Documentation
¶
Overview ¶
Package skilltool provides the standard tools for the skill toolset.
Index ¶
- func ListSkills(source skill.Source) (tool.Tool, error)
- func LoadSkill(source skill.Source) (tool.Tool, error)
- func LoadSkillResource(source skill.Source) (tool.Tool, error)
- func SkillsToXML(frontmatters []*skill.Frontmatter) string
- type FrontmatterJSON
- type ListSkillsArgs
- type ListSkillsResult
- type LoadSkillArgs
- type LoadSkillResourceArgs
- type LoadSkillResourceResult
- type LoadSkillResult
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ListSkills ¶
ListSkills creates a tool.Tool to list available skills.
func LoadSkillResource ¶
LoadSkillResource creates a tool.Tool to load a resource file for a skill.
func SkillsToXML ¶
func SkillsToXML(frontmatters []*skill.Frontmatter) string
Types ¶
type FrontmatterJSON ¶
type FrontmatterJSON struct {
Name string `json:"name"`
Description string `json:"description"`
License string `json:"license,omitempty"`
Compatibility string `json:"compatibility,omitempty"`
Metadata map[string]string `json:"metadata,omitempty"`
AllowedTools []string `json:"allowed-tools,omitempty"`
}
type ListSkillsArgs ¶
type ListSkillsArgs struct{}
ListSkillsArgs represents the input for ListSkills tool.
type ListSkillsResult ¶
type ListSkillsResult struct {
SkillsXML string `json:"skills"`
}
ListSkillsResult represents the output for ListSkills tool.
type LoadSkillArgs ¶
type LoadSkillArgs struct {
Name string `json:"name" jsonschema:"The name of the skill to load."`
}
LoadSkillArgs represents the input to load a skill.
type LoadSkillResourceArgs ¶
type LoadSkillResourceArgs struct {
SkillName string `json:"skill_name" jsonschema:"The name of the skill."`
ResourcePath string `` /* 145-byte string literal not displayed */
}
LoadSkillResourceArgs represents the input for retrieving a resource out of a skill's resources.
type LoadSkillResourceResult ¶
type LoadSkillResourceResult struct {
SkillName string `json:"skill_name,omitempty"`
Path string `json:"path,omitempty"`
Content string `json:"content,omitempty"`
}
LoadSkillResourceResult encapsulates the resource content.
type LoadSkillResult ¶
type LoadSkillResult struct {
SkillName string `json:"skill_name,omitempty"`
Instructions string `json:"instructions,omitempty"`
Frontmatter *FrontmatterJSON `json:"frontmatter,omitempty"`
}
LoadSkillResult represents the output of a loaded skill.
Click to show internal directories.
Click to hide internal directories.